diff --git a/htdocs/ticket/card.php b/htdocs/ticket/card.php
index 9c1a7c709b7..1b3dd4c8e37 100644
--- a/htdocs/ticket/card.php
+++ b/htdocs/ticket/card.php
@@ -700,7 +700,7 @@ if ($action == 'create' || $action == 'presend') {
$formticket->withextrafields = 1;
$formticket->param = array('origin' => GETPOST('origin'), 'originid' => GETPOST('originid'));
- $formticket->showForm(1, 'create', 0);
+ $formticket->showForm(1, 'create', 0, null, $action);
/*} elseif ($action == 'edit' && $user->rights->ticket->write && $object->fk_statut < Ticket::STATUS_CLOSED) {
$formticket = new FormTicket($db);
diff --git a/htdocs/core/class/html.formticket.class.php b/htdocs/core/class/html.formticket.class.php
index 7d116fd692a..cea007f8e61 100644
--- a/htdocs/core/class/html.formticket.class.php
+++ b/htdocs/core/class/html.formticket.class.php
@@ -127,12 +127,14 @@ class FormTicket
/**
* Show the form to input ticket
*
* @param int $withdolfichehead With dol_get_fiche_head() and dol_get_fiche_end()
* @param string $mode Mode ('create' or 'edit')
* @param int $public 1=If we show the form for the public interface
* @return void
*/
- public function showForm($withdolfichehead = 0, $mode = 'edit', $public = 0)
+ public function showForm($withdolfichehead = 0, $mode = 'edit', $public = 0, Contact $with_contact = null, $action = '')
{
global $conf, $langs, $user, $hookmanager;
@@ -441,7 +443,7 @@ class FormTicket
// Other attributes
$parameters = array();
- $reshook = $hookmanager->executeHooks('formObjectOptions', $parameters, $ticketstat, $this->action); // Note that $action and $object may have been modified by hook
+ $reshook = $hookmanager->executeHooks('formObjectOptions', $parameters, $ticketstat, $action); // Note that $action and $object may have been modified by hook
if (empty($reshook)) {
print $ticketstat->showOptionals($extrafields, 'create');
}
@@ -127,12 +127,14 @@ class FormTicket
* Show the form to input ticket
*
- * @param int $withdolfichehead With dol_get_fiche_head() and dol_get_fiche_end()
- * @param string $mode Mode ('create' or 'edit')
- * @param int $public 1=If we show the form for the public interface
+ * @param int $withdolfichehead With dol_get_fiche_head() and dol_get_fiche_end()
+ * @param string $mode Mode ('create' or 'edit')
+ * @param int $public 1=If we show the form for the public interface
+ * @param Contact|null $with_contact [=NULL] Contact to link to this ticket if exists
+ * @param string $action [=''] Action in card
* @return void
*/